package com.menagerie.ophelia

import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.animation.SharedTransitionLayout
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.menagerie.ophelia.ui.theme.OpheliaTheme
import com.menagerie.ophelia.sensor.SensorManager
import com.menagerie.ophelia.model.recipesList
import com.menagerie.ophelia.recipesdetails.RecipeDetails
import com.menagerie.ophelia.recipeslist.RecipesListScreen
import com.menagerie.ophelia.sensor.SensorManager
import com.menagerie.ophelia.ui.theme.OpheliaTheme
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.launch

enum class Theme {
    Auto,
    Light,
    Dark
}

enum class DetailListAppScreen {
    List,
    Details,
}

@OptIn(ExperimentalSharedTransitionApi::class)
@Composable
fun App(sensorManager: SensorManager?, isLarge: Boolean = false) {

    val navController = rememberNavController()

    var currentTheme by rememberSaveable { mutableStateOf(Theme.Light)}
    val isDarkTheme: Boolean? = when (currentTheme) {
        Theme.Dark -> true
        Theme.Light -> false
        Theme.Auto -> null
    }

    val onThemeToggle = {
        currentTheme = when (currentTheme) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
    }

    OpheliaTheme(isDarkTheme ?: isSystemInDarkTheme()) {

        //TODO : Replace/Duplicate This and use it to show Polycule Members instead.
        //TODO : Move this to its own page
        val items by remember { mutableStateOf(recipesList) }
        var currentRecipe = items.first()

        NavHost(
            navController = navController,
            startDestination = DetailListAppScreen.List.name,
            modifier = Modifier.fillMaxSize()
        ) {
            composable(route = DetailListAppScreen.List.name) {
                RecipesListScreen(
                    isLarge = isLarge,
                    items = items,
                    onClick = { recipe ->
                        currentRecipe = recipe
                        navController.navigate(DetailListAppScreen.Details.name)
                    })
            }
            composable(route = DetailListAppScreen.Details.name) {
                RecipeDetails(
                    isLarge = isLarge,
                    sensorManager = sensorManager,
                    recipe = currentRecipe,
                    goBack = { navController.popBackStack() }
                )
            }

            }
        }

//        Scaffold {
//            var showContent by remember { mutableStateOf(false) }
//            Column(Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
//                Row {
//                    Button(onClick = { showContent = !showContent }) {
//                        Text("Click Me!")
//                    }
//                    Button(onClick = onThemeToggle){
//                        val text : String = currentTheme.name
//                        Text(text)
//                    }
//                }
//                AnimatedVisibility(showContent) {
//                    val greeting = remember { Greeting().greet() }
//                    Column(
//                        Modifier.fillMaxWidth(),
//                        horizontalAlignment = Alignment.CenterHorizontally
//                    ) {
//                        Image(painterResource(Res.drawable.ophelia), null)
//                        Text("Compose: $greeting")
//                    }
//                }
//            }
//        }
    }
}
